@@ -375,5 +375,8 @@ ADD  `fixed_next_time` int(10) unsigned NOT NULL;");
                 @$db->updatequery("ALTER TABLE  `auto_ussd` ADD INDEX (  `recharge_con_type` )");
 	}
 
+	@$db->updatequery("ALTER TABLE `message` ADD `resend` int(11) NOT NULL default '0'");
+
+/*1.24.1 fixed bug of provider with ' */
 	echo "update done! <a href=''  target=_top>Return</a>";
 ?>
